@@ -14,5 +14,6 @@ from reliability import ALT_fitters
 from reliability import ALT_probability_plotting
 from reliability import PoF
 from reliability import Utils
+from reliability import Convert_data
 
-__version__ = '0.5.4' #Current version
+__version__ = "0.5.5"  # Current version
